function bpfplot(f0,bw,n,fs,ff)
% BPFPLOT -- Plot a bandpass filter response on result of SIGSPEC plot
%
% BPFPLOT(F0,BW,N,FS,FF) overplots a bandpass filter response on top of
% the result of a SIGSPEC plot. The bandpass filter specifications are the
% same as for BPF.  BPFPLOT overplots on the most recent plot generated, so
% it would be best to call BPFPLOT immediately after calling SIGSPEC.
%
% See also TIMEFREQ, OSC, MIXER, FWRECT, LPF, BPF, SIGSPEC, BPFPLOT, LPFPLOT

% Select the spectrum plot
subplot(2,1,1)
hold on

% Filter coefficients
[b a]=butter(n,[f0-(bw/2) f0+(bw/2)]/(fs/2));

% Frequency response
[H,F]=freqz(b,a,fs/2,fs);
HH=[H(fs/2:-1:1); H];

% Overplot the filter response
plot(ff/1e3,abs(HH),'r:')
